import express from 'express';
import cors from 'cors';
import helmet from 'helmet';
import supertokens from 'supertokens-node';
import { middleware, errorHandler } from 'supertokens-node/framework/express';
import dotenv from 'dotenv';
import { getRecipeList } from './recipeList';

dotenv.config();

const apiPort = process.env.API_PORT!;
const apiDomain = `http://localhost:${apiPort}`;

const websitePort = process.env.WEBSITE_PORT!;
const websiteDomain = `http://localhost:${websitePort}`;

supertokens.init({
    framework: 'express',
    supertokens: {
        connectionURI: 'http://localhost:3567',
    },
    appInfo: {
        appName: 'dumpster_fire',
        apiDomain,
        websiteDomain,
    },
    recipeList: getRecipeList(),
});

const app = express();

app.use(
    cors({
        origin: websiteDomain,
        allowedHeaders: ['content-type', ...supertokens.getAllCORSHeaders()],
        methods: ['GET', 'PUT', 'POST', 'DELETE'],
        credentials: true,
    })
);
app.use(helmet({ contentSecurityPolicy: false }));
app.use(middleware());
app.use(errorHandler());
app.use(
    (
        err: any,
        req: express.Request<any>,
        res: express.Response<any>,
        next: express.NextFunction
    ) => {
        res.status(500).send('Internal error: ' + err.message);
    }
);

app.listen(apiPort, () =>
    console.log(`API Server listening on port ${apiPort}`)
);
