import { CardPrice } from '@components/common/ListingCard/CardPrice';
import { CardTitle } from '@components/common/ListingCard/CardTitle';
import { useRouter } from '@hooks/useRouter';
import { Base } from '@layouts/Base';
import { Divider } from '@mui/material';
import {
    List_ListingFragment,
    useGetListingQuery,
    useGetUserProfileQuery,
} from 'gql/generated/react';
import Image from 'next/image';
import React, { FC } from 'react';
import { Card, Container, Stack } from 'ui';

export interface ListingProps {
    listing: List_ListingFragment;
}

export const Listing: FC<ListingProps> = () => {
    const router = useRouter();
    const id = router.query.id as string;
    const response = useGetListingQuery({ variables: { id }, skip: !id });
    const listing = response?.data?.app_listings_by_pk;
    const user = useGetUserProfileQuery({ variables: listing?.creator })?.data
        ?.app_users_by_pk;

    if (!listing) {
        return <div>404</div>;
    }

    if (!user) {
        return (
            <div>Listing author not found. Something went terribly wrong!</div>
        );
    }

    const image =
        listing.thumbnail?.link ??
        'https://s3.amazonaws.com/s3.timetoast.com/public/uploads/photo/9546195/image/ee55f99031df4782b4fe49e860dfc5a4';

    return (
        <Base>
            <Container maxWidth={'xl'} sx={{ marginTop: '100px' }}>
                <Card>
                    <Stack direction={'row'}>
                        <Container maxWidth="md">
                            {listing.thumbnail ? (
                                <Image
                                    src={image}
                                    alt={listing.title}
                                    width={500}
                                    height={500}
                                ></Image>
                            ) : null}
                        </Container>
                        <Divider flexItem={true} orientation="vertical" />
                        <Stack
                            direction={'column'}
                            sx={{ marginLeft: '4rem' }}
                            gap={'3rem'}
                        >
                            <h2>{listing.title}</h2>
                            <div>{listing.description}</div>
                            <CardPrice
                                price={listing.price}
                                currency={listing.currency}
                            ></CardPrice>
                            <Stack direction={'row'} gap="50px">
                                <div>{user.name}</div>
                                <div>{user.email}</div>
                            </Stack>
                        </Stack>
                    </Stack>
                </Card>
            </Container>
        </Base>
    );
};
