import { useRouter } from '@hooks/useRouter';
import { List_ListingFragment } from 'gql/generated/react';
import Image from 'next/image';
import Link from 'next/link';
import { title } from 'process';
import React, { FC } from 'react';
import { paths } from 'src/pages/pages';
import { theme_dark } from 'theme';
import { Card, Container, Stack } from 'ui';
import { CardDescription } from './CardDescription';
import { CardImage } from './CardImage';
import { CardPrice } from './CardPrice';
import { CardTitle } from './CardTitle';

export type ListingCardProps = {
    listing: List_ListingFragment;
};
export type ListingCardType = FC<ListingCardProps>;

export const ListingCard: ListingCardType = ({ listing }) => {
    console.log(listing.thumbnail?.id);
    const image =
        listing.thumbnail?.link ??
        'https://s3.amazonaws.com/s3.timetoast.com/public/uploads/photo/9546195/image/ee55f99031df4782b4fe49e860dfc5a4';

    return (
        <Link href={`${paths.Listing}/${listing.id}`}>
            <Card
                sx={{
                    '&:hover': {
                        boxShadow: theme_dark.shadows.cardHover,
                        backgroundImage: theme_dark.colors.primary,
                        cursor: 'pointer',
                    },
                }}
            >
                <Stack direction={'column'} alignItems={'stretch'}>
                    {listing.thumbnail ? (
                        <CardImage src={image} alt={title} />
                    ) : null}
                    <Stack direction={'column'} marginLeft="10px">
                        <CardTitle>{listing.title}</CardTitle>
                        <CardPrice
                            price={listing.price}
                            currency={listing.currency}
                        ></CardPrice>
                    </Stack>
                </Stack>
            </Card>
        </Link>
    );
};
