import * as React from 'react';
import AppBar from '@mui/material/AppBar';
import Box from '@mui/material/Box';
import Toolbar from '@mui/material/Toolbar';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import Menu from '@mui/material/Menu';
import MenuIcon from '@mui/icons-material/Menu';
import Container from '@mui/material/Container';
import Avatar from '@mui/material/Avatar';
import Tooltip from '@mui/material/Tooltip';
import SearchIcon from '@mui/icons-material/Search';
import MenuItem from '@mui/material/MenuItem';
import { theme_dark } from 'theme';
import InputBase from '@mui/material/InputBase';
import { Logo } from './Logo';
import { paths } from 'src/pages/pages';
import { useRouter } from '@hooks/useRouter';
import {
    DesktopMenuButton,
    MobileMenuButton,
} from '@components/common/MenuButton';

// const router = useRouter();
const settings = ['Profile', 'Account', 'My listings', 'Logout'];

// const Search =
// styled('div')`
//     position: 'relative';
//     border-radius: '10px';
//     background-color: 'rgba(255,255,255,0.15)';
//     &:hover {
//         background-color: 'rgba(255,255,255,0.25)';
//     }
//     margin-right: '25px';
//     width: '25%';
// `;

// const StyledInputBase =
//  styled(InputBase)`
//     color: 'inherit';
//     & .muiinputbase-input {
//         width: '10%';
//     }
// `;

// const SearchIconWrapper =
//  styled.div`
//     height: '100%';
//     position: 'absolute';
//     pointer-events: 'none';
//     display: 'flex';
//     align-items: 'center';
//     justify-content: 'center';
// `;

const ResponsiveAppBar = () => {
    const [anchorElNav, setAnchorElNav] = React.useState<null | HTMLElement>(
        null
    );
    const [anchorElUser, setAnchorElUser] = React.useState<null | HTMLElement>(
        null
    );

    const handleOpenNavMenu = (event: React.MouseEvent<HTMLElement>) => {
        setAnchorElNav(event.currentTarget);
    };
    const handleOpenUserMenu = (event: React.MouseEvent<HTMLElement>) => {
        setAnchorElUser(event.currentTarget);
    };

    const handleCloseNavMenu = () => {
        setAnchorElNav(null);
    };

    const handleCloseUserMenu = () => {
        setAnchorElUser(null);
    };

    return (
        <AppBar
            position="sticky"
            sx={{ backgroundImage: theme_dark.colors.primary }}
        >
            <Container maxWidth="xl">
                <Toolbar disableGutters>
                    <Logo />
                    <Box
                        sx={{
                            flexGrow: 1,
                            display: { xs: 'flex', md: 'none' },
                        }}
                    >
                        <IconButton
                            size="large"
                            aria-label="account of current user"
                            aria-controls="menu-appbar"
                            aria-haspopup="true"
                            onClick={handleOpenNavMenu}
                            color="inherit"
                        >
                            <MenuIcon />
                        </IconButton>
                        <Menu
                            id="menu-appbar"
                            anchorEl={anchorElNav}
                            anchorOrigin={{
                                vertical: 'bottom',
                                horizontal: 'left',
                            }}
                            keepMounted
                            transformOrigin={{
                                vertical: 'top',
                                horizontal: 'left',
                            }}
                            open={Boolean(anchorElNav)}
                            onClose={handleCloseNavMenu}
                            sx={{
                                display: { xs: 'block', md: 'none' },
                            }}
                        >
                            {Object.entries(paths).map(
                                ([pageName, pagePath]) => (
                                    <MobileMenuButton
                                        text={pageName}
                                        path={pagePath}
                                        onClick={handleCloseNavMenu}
                                    />
                                )
                            )}
                        </Menu>
                    </Box>
                    <Box
                        sx={{
                            flexGrow: 1,
                            display: { xs: 'none', md: 'flex' },
                        }}
                    >
                        {Object.entries(paths).map(([pageName, pagePath]) => (
                            <DesktopMenuButton
                                text={pageName}
                                path={pagePath}
                            />
                        ))}
                    </Box>
                    {/* <Search>
                        <SearchIconWrapper> 
                            <SearchIcon />
                        </SearchIconWrapper>
                        <StyledInputBase
                            placeholder="Search…"
                            inputProps={{ 'aria-label': 'search' }}
                        />
                    </Search> */}
                    <Box sx={{ flexGrow: 0 }}>
                        <Tooltip title="Open settings">
                            <IconButton
                                onClick={handleOpenUserMenu}
                                sx={{ p: 0 }}
                            >
                                <Avatar />
                            </IconButton>
                        </Tooltip>
                        <Menu
                            sx={{ mt: '45px' }}
                            id="menu-appbar"
                            anchorEl={anchorElUser}
                            anchorOrigin={{
                                vertical: 'top',
                                horizontal: 'right',
                            }}
                            keepMounted
                            transformOrigin={{
                                vertical: 'top',
                                horizontal: 'right',
                            }}
                            open={Boolean(anchorElUser)}
                            onClose={handleCloseUserMenu}
                        >
                            {settings.map((setting) => (
                                <MenuItem
                                    key={setting}
                                    onClick={handleCloseUserMenu}
                                >
                                    <Typography textAlign="center">
                                        {setting}
                                    </Typography>
                                </MenuItem>
                            ))}
                        </Menu>
                    </Box>
                </Toolbar>
            </Container>
        </AppBar>
    );
};
export default ResponsiveAppBar;
