import React, { FC } from 'react';
import { ApolloProvider } from '@apollo/client';
import { useNProgress } from '@hooks/useNProgress';
import { useInitApolloClient } from '@hooks/useInitApolloClient';
import { initAuth } from '@utils/auth/supertokens';
import CssBaseline from '@mui/material/CssBaseline';
import { EnhancedAppProps } from '@typings/EnhancedAppProps';
import createCache from '@emotion/cache';
import { CacheProvider } from '@emotion/react';

// authorization
initAuth();
const cache = createCache({ key: 'next-mui' });

const App: FC<EnhancedAppProps> = ({ Component, pageProps }) => {
    useNProgress();
    const client = useInitApolloClient(pageProps.initialApolloState);

    return (
        // why would you use a provider for a cache? that's retarded
        <CacheProvider value={cache}>
            <ApolloProvider client={client}>
                {/*<MockedProvider mocks={mocks}>*/}
                <Component {...pageProps} />
                <CssBaseline />
                {/*</MockedProvider>*/}
            </ApolloProvider>
        </CacheProvider>
    );
};

export default App;
